@@ -27,10 +27,20 @@ fail=0
 
 printf "testing lzd-%s..." "$2"
 
-"${LZIP}" < "${in_lz}" | cmp "${in}" - || fail=1
+"${LZIP}" < "${in}" 2> /dev/null
+if [ $? = 2 ] ; then printf . ; else fail=1 ; printf - ; fi
+dd if="${in_lz}" bs=1 count=6 2> /dev/null | "${LZIP}" 2> /dev/null
+if [ $? = 2 ] ; then printf . ; else printf - ; fail=1 ; fi
+dd if="${in_lz}" bs=1 count=20 2> /dev/null | "${LZIP}" 2> /dev/null
+if [ $? = 2 ] ; then printf . ; else printf - ; fail=1 ; fi
+
+"${LZIP}" < "${in_lz}" > copy || fail=1
+cmp "${in}" copy || fail=1
 printf .
+
+cat "${in}" "${in}" > in2 || framework_failure
 cat "${in_lz}" "${in_lz}" | "${LZIP}" > copy2 || fail=1
-cat "${in}" "${in}" | cmp copy2 - || fail=1
+cmp in2 copy2 || fail=1
 printf .
 
 echo
